import { GraphElement } from "./graphelement";

export interface ColorData { r: number, g: number, b: number }

export interface NodeTypeData {
    id: number;
    name: string;
    color?: ColorData;
}

export class NodeType
    extends GraphElement<NodeTypeData, NodeTypeData>
    implements NodeTypeData {
    public id: number;
    public name: string;
    public color: ColorData;

    constructor(name?: string, color?: ColorData) {
        super(0);
        this.name = name;
        this.color = color;
    }

    toJSONSerializableObject(): NodeTypeData {
        return { id: this.id, name: this.name, color: this.color };
    }

    toHistorySerializableObject(): NodeTypeData {
        return this.toJSONSerializableObject();
    }

    public fromSerializedObject(data: NodeTypeData): NodeType {
        Object.assign(this, data);
        return this;
    }

    public toString(): string {
        return this.name;
    }

    public equals(other: GraphElement<NodeTypeData, NodeTypeData>): boolean {
        if (other.constructor != this.constructor) {
            return false;
        }

        const type = other as NodeType;

        return type.id === this.id;
    }
}
