import React, { useEffect, useState } from "react";
import "./nodetypeseditor.css";
import NodeTypeEntry from "./nodetypeentry";
import { NodeType, NodeTypeData } from "../../common/graph/nodetype";

type NodeTypesEditorProps = {
    nodeTypes: NodeType[];
    onNodeTypeSelect: (type: NodeType) => void;
    onNodeTypeCreation: () => NodeType;
    onNodeTypeDelete: (id: number[]) => void;
    onNodeTypeDataChange: (
        requests: NodeTypeData[],
        createCheckpoint?: boolean
    ) => void;
    createCheckpoint: (description: string) => void;
};

function NodeTypesEditor({
    nodeTypes,
    onNodeTypeSelect,
    onNodeTypeCreation,
    onNodeTypeDelete,
    onNodeTypeDataChange,
    createCheckpoint,
}: NodeTypesEditorProps) {
    const [selectedType, setSelectedType] = useState<NodeType>(nodeTypes[0]); // There should always exist at least one NodeType object

    useEffect(() => {
        setSelectedType(nodeTypes[0]);
    }, [nodeTypes]);

    const selectTypeWithId = (id: number) =>
        setSelectedType(nodeTypes.find((type: NodeType) => type.id == id));

    const handleNodeTypeCreation = () => {
        const newNodeType = onNodeTypeCreation();

        // Select new type
        setSelectedType(newNodeType);
    };

    const handleNodeTypeDelete = (ids: number[]) => {
        onNodeTypeDelete(ids);

        // Selete other type => Try first element that will not be delete
        const newSelectedType = nodeTypes.find(
            (nodeType: NodeType) => !ids.includes(nodeType.id)
        );
        setSelectedType(newSelectedType);
    };

    return (
        <div id="node-types-editor">
            <button onClick={handleNodeTypeCreation}>Add type</button>
            <br />
            <select
                onChange={(e) => selectTypeWithId(Number(e.target.value))}
                value={selectedType.id}
            >
                {nodeTypes.map((nodeType: NodeType, index: number) => (
                    <option
                        key={nodeType.id}
                        value={nodeType.id}
                        selected={index === 0}
                    >
                        {nodeType.name}
                    </option>
                ))}
            </select>
            <hr />
            <NodeTypeEntry
                nodeType={selectedType}
                onNodeTypeSelect={onNodeTypeSelect}
                onNodeTypeDelete={handleNodeTypeDelete}
                onNodeTypeDataChange={onNodeTypeDataChange}
                enableDelete={nodeTypes.length > 1}
                createCheckpoint={createCheckpoint}
            />
        </div>
    );
}

export default NodeTypesEditor;
